@@ -1,14 +1,13 @@
 package Dist::Zilla::PluginBundle::Author::REFECO;
-# ABSTRACT: REFECO dists defaults
+# ABSTRACT: REFECO dist defaults
 
 use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:REFECO';    # AUTHORITY
-our $VERSION   = '0.006';          # VERSION
+our $VERSION   = '0.007';          # VERSION
 
-use Moose 2.2206;
-use namespace::clean;
+use Moose;
 use Dist::Zilla 6.030;
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -17,7 +16,7 @@ sub configure {
 
     my $self = shift;
 
-    my @copy = qw(Makefile.PL LICENSE cpanfile INSTALL t/00-check-deps.t t/00-compile.t);
+    my @copy = qw(Makefile.PL LICENSE cpanfile);
 
     $self->add_bundle(
         'Filter' => {
@@ -41,9 +40,8 @@ sub configure {
                 locate_comment => 1
             }
         ],
-        'InstallGuide',
         'PodWeaver',
-        'PerlTidy',
+        ['PerlTidy' => {perltidyrc => '.perltidyrc'}],
         [
             'ReadmeAnyFromPod' => 'Git' => {
                 filename => 'README.md',
@@ -52,28 +50,22 @@ sub configure {
                 phase    => 'build'
             }
         ],
+        'NextRelease',
+        'MetaJSON',
         [
-            'ReadmeAnyFromPod' => 'Dist' => {
-                filename => 'README',
-                location => 'build',
-                type     => 'text'
+            'GithubMeta' => {
+                issues => 1,
             }
         ],
-        'NextRelease',
-        'CPANFile',
-        'MetaJSON',
-        'GithubMeta',
         'MetaProvides::Package',
-        'Prereqs::AuthorDeps',
+        'CPANFile',
         'Test::Compile',
         'Test::CheckDeps',
-        'Test::Portability',
-        'Test::Legal',
-        'Test::Perl::Critic',
-        'Test::DistManifest',
+        ['Test::Perl::Critic' => {critic_config => '.perlcriticrc'}],
         'PodSyntaxTests',
-        'MojibakeTests',
-        'MetaTests'
+        'MetaTests',
+        'TestRelease',
+        'ConfirmRelease',
     );
 }
 
@@ -87,11 +79,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::PluginBundle::Author::REFECO - REFECO dists defaults
+Dist::Zilla::PluginBundle::Author::REFECO - REFECO dist defaults
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 OVERVIEW
 
@@ -108,20 +100,16 @@ Reproducible by the following dist.ini config:
     exclude_filename = Makefile.PL
     exclude_filename = LICENSE
     exclude_filename = cpanfile
-    exclude_filename = INSTALL
     include_dotfiles = 1
 
     [PruneCruft]
-    exclude = .perlcriticrc
-    exclude = .perltidyrc
+    except = .perlcriticrc
+    except = .perltidyrc
 
     [CopyFilesFromBuild]
     copy = Makefile.PL
     copy = LICENSE
     copy = cpanfile
-    copy = INSTALL
-    copy = t/00-check-deps.t
-    copy = t/00-compile.t
 
     [OurPkgVersion]
     [Test::Version]
@@ -130,37 +118,36 @@ Reproducible by the following dist.ini config:
     authority = cpan:REFECO
     locate_comment = 1
 
-    [InstallGuide]
     [PodWeaver]
     [PerlTidy]
+    perltidyrc = .perltidyrc
 
-    [ReadmeAnyFromPod / ReadmePodInRoot]
+    [ReadmeAnyFromPod]
     type = gfm
     filename = README.md
     location = root
     phase = build
 
-    [ReadmeAnyFromPod]
-    type = text
-    filename = README
-    location = build
-
     [NextRelease]
     [CPANFile]
     [MetaJSON]
+
     [GithubMeta]
+    issues = 1
+
     [MetaProvides::Package]
-    [Prereqs::AuthorDeps]
     [Test::Compile]
     [Test::CheckDeps]
-    [Test::Portability]
-    [Test::Legal]
+
     [Test::Perl::Critic]
-    [Test::DistManifest]
+    critic_config = .perlcriticrc
+
     [PodSyntaxTests]
-    [MojibakeTests]
     [MetaTests]
 
+    [TestRelease]
+    [ConfirmRelease]
+
 =head1 AUTHOR
 
 Reginaldo Costa <refeco@cpan.org>
